aboutsummaryrefslogtreecommitdiffstats
path: root/sonar-plugin-api
diff options
context:
space:
mode:
authorJulien HENRY <julien.henry@sonarsource.com>2013-09-23 17:26:16 +0200
committerJulien HENRY <julien.henry@sonarsource.com>2013-09-23 17:27:59 +0200
commitc35c6ba856dc4270e4c29233919c6bf5a06a648b (patch)
tree1a334bdccf1888fad8cfccad1df19740e6d005e1 /sonar-plugin-api
parent38b47dc6dec25d251a0b89498fd13de59931c1f6 (diff)
downloadsonarqube-c35c6ba856dc4270e4c29233919c6bf5a06a648b.tar.gz
sonarqube-c35c6ba856dc4270e4c29233919c6bf5a06a648b.zip
SONAR-4689 Batch API to get issues of the current project
Diffstat (limited to 'sonar-plugin-api')
-rw-r--r--sonar-plugin-api/src/main/java/org/sonar/api/issue/ProjectIssues.java (renamed from sonar-plugin-api/src/main/java/org/sonar/api/issue/ModuleIssues.java)16
1 files changed, 11 insertions, 5 deletions
diff --git a/sonar-plugin-api/src/main/java/org/sonar/api/issue/ModuleIssues.java b/sonar-plugin-api/src/main/java/org/sonar/api/issue/ProjectIssues.java
index 2f1a974f51c..36659896d68 100644
--- a/sonar-plugin-api/src/main/java/org/sonar/api/issue/ModuleIssues.java
+++ b/sonar-plugin-api/src/main/java/org/sonar/api/issue/ProjectIssues.java
@@ -20,22 +20,28 @@
package org.sonar.api.issue;
import org.sonar.api.BatchComponent;
+import org.sonar.api.batch.InstantiationStrategy;
+import org.sonar.api.batch.PostJob;
+
+import static org.sonar.api.batch.InstantiationStrategy.PER_BATCH;
/**
- * Used by batch components to get the issues of the current module. It does not allow
- * to get issues of all project modules.
+ * Used by batch components to get the issues of the project. You have to wait for all
+ * issues to have been computed (for example in a {@link PostJob}) to be sure all issues have
+ * been computed.
*
* @since 4.0
*/
-public interface ModuleIssues extends BatchComponent {
+@InstantiationStrategy(PER_BATCH)
+public interface ProjectIssues extends BatchComponent {
/**
* All the unresolved issues of the current module, including the issues reported by end-users.
*/
Iterable<Issue> issues();
/**
* All the issues of this module that have been marked as resolved during this scan
*/
Iterable<Issue> resolvedIssues();
}
@@ -20,22 +20,28 @@
/**
- * All the unresolved issues of the current module, including the issues reported by end-users.
+ * All the unresolved issues of the project, including the issues reported by end-users.
*/
Iterable<Issue> issues();
@@ -20,22 +20,28 @@
Iterable<Issue> issues();
/**
- * All the issues of this module that have been marked as resolved during this scan
+ * All the issues of this project that have been marked as resolved during this scan
*/
Iterable<Issue> resolvedIssues();